@@ -13,7 +13,9 @@ logger = LoggerJsonFile().logger
 
 
 class FaceAnalyzer(object):
-    @Timer("FaceAnalyzer.__init__", "{name}: {milliseconds:.2f} ms", logger.debug)
+    @Timer(
+        "FaceAnalyzer.__init__", "{name}: {milliseconds:.2f} ms", logger=logger.debug
+    )
     def __init__(self, cfg: OmegaConf):
         """FaceAnalyzer is the main class that reads images, runs face detection, tensor unification and facial feature prediction.
         It also draws bounding boxes and facial landmarks over the image.
@@ -70,7 +72,7 @@ class FaceAnalyzer(object):
                 self.cfg.utilizer[utilizer_name]
             )
 
-    @Timer("FaceAnalyzer.run", "{name}: {milliseconds:.2f} ms", logger.debug)
+    @Timer("FaceAnalyzer.run", "{name}: {milliseconds:.2f} ms", logger=logger.debug)
     def run(
         self,
         path_image: str,
@@ -115,6 +117,8 @@ class FaceAnalyzer(object):
         self.logger.info("Running FaceAnalyzer")
         self.logger.info("Reading image", extra={"path_image": path_image})
         data = self.reader.run(path_image, fix_img_size=fix_img_size)
+        path_output = None if path_output == "None" else path_output
+        data.path_output = path_output
         data.version = pkg_resources.get_distribution("facetorch").version
 
         self.logger.info("Detecting faces")
@@ -131,13 +135,13 @@ class FaceAnalyzer(object):
                 self.logger.info(f"Running FacePredictor: {predictor_name}")
                 data = _predict_batch(data, predictor, predictor_name)
 
-            path_output = None if path_output == "None" else path_output
-            data.path_output = path_output
-
             self.logger.info("Utilizing facial features")
             for utilizer_name, utilizer in self.utilizers.items():
                 self.logger.info(f"Running BaseUtilizer: {utilizer_name}")
                 data = utilizer.run(data)
+        else:
+            if "save" in self.utilizers:
+                self.utilizers["save"].run(data)
 
         if not include_tensors:
             self.logger.debug(
